@@ -1,5 +1,5 @@
 from ._helpers import isochoric_volumetric_split
-from ..math import det, transpose, trace, eigvals, sum1
+from ..math import det, transpose, trace, eigvals, sum1, log, inv, sqrt
 
 
 def saint_venant_kirchhoff(F, mu, lmbda):
@@ -73,3 +73,26 @@ def arruda_boyce(F, C1, limit):
         out += a * beta ** (2 * j - 2) * (I1 ** j - 3 ** j)
 
     return C1 * out
+
+
+@isochoric_volumetric_split
+def extended_tube(F, Gc, delta, Ge, beta):
+    C = transpose(F) @ F
+    D = trace(C)
+    wC = eigvals(C)
+    g = (1 - delta ** 2) * (D - 3) / (1 - delta ** 2 * (D - 3))
+    Wc = Gc / 2 * (g + log(1 - delta ** 2 * (D - 3)))
+    We = 2 * Ge / beta ** 2 * sum1(wC ** (-beta / 2) - 1)
+    return Wc + We
+
+
+@isochoric_volumetric_split
+def van_der_waals(F, mu, limit, a, beta):
+    C = transpose(F) @ F
+    I1 = trace(C)
+    I2 = (trace(C) ** 2 - trace(C @ C)) / 2
+    I = (1 - beta) * I1 + beta * I2
+    eta = sqrt((I - 3) / (limit ** 2 - 3))
+    return mu * (
+        -(limit ** 2 - 3) * (log(1 - eta) + eta) - 2 / 3 * a * ((I - 3) / 2) ** (3 / 2)
+    )
